@@ -44,3 +44,27 @@ given ( $ARGV[0] ) {
     when ('current-version') { current_version() }
 }
 
+
+=head1 NAME
+grimlock_deploy_schema.pl - MAKE DATABASE FOR GRIMLOCK BLOG
+
+=head1 SYNOPSIS
+
+grimlock_deploy_schema.pl install
+
+=head1 DESCRIPTION
+
+MAKE DATABASE FOR GRIMLOCK BLOG SO IT CAN SAVE BLOGS ABOUT CESIUM SALAMI AND BERYLLIUM BALONEY
+
+=head1 AUTHORS
+
+ME, GRIMLOCK!
+
+=head1 COPYRIGHT
+
+ME GRIMLOCK WANT SHARE BEAUTIFUL SOFTWARE ME WRITE WITH WORLD.  ME GRIMLOCK SAY THIS SOFTWARE RELEASE UNDER ARTISTIC LICENSE.
+
+SEE L<perlartistic>.
+
+=cut
+
